@@ -32,7 +32,7 @@
 jsPropensityGadget <- function(data, nfactor.limit = 20){
 
   requireNamespace("survival")
-  requireNamespace("survC1")
+  #requireNamespace("survC1")
 
   ## To remove NOTE.
   ID.pscal2828 <- level <- val_label <- BinaryGroupRandom <- variable <- NULL
